@@ -3,86 +3,50 @@
 #   | | | '_ \| / __| | / __| | |_) | | '_ \| | | | |/ _` | __/ _ \
 #   | | | | | | \__ \ | \__ \ |  __/| | |_) | |_| | | (_| | ||  __/
 #   |_| |_| |_|_|___/ |_|___/ |_|   |_| .__/ \__,_|_|\__,_|\__\___|
-# There are many frameworks like it,  |_| but this one is mine. --MikeL
+# Push Pandas DataFrames into GSheets |_| for Dashboards and more. 
 
 
 import ohawf
 import gspread
 import pandas as pd
+from sys import exit
 from sys import stdout
 from inspect import getsource
-from sys import exc_info as error
 from apiclient.discovery import build
 
 
 gspread_sheet = None
 column_uniqueness = False
-err = lambda: print(error()[0].__name__)
-
-jn = True
-try:
-    get_ipython()
-except NameError:
-    jn = False
-    h1 = lambda x: print(f"# {x}")
-    h2 = lambda x: print(f"## {x}")
-    h3 = lambda x: print(f"### {x}")
-    h4 = lambda x: print(f"#### {x}")
-    h5 = lambda x: print(f"##### {x}")
-    h6 = lambda x: print(f"###### {x}")
-
-
-if jn:
-    from IPython.display import display, Markdown
-
-    h1 = lambda x: display(Markdown(f"# {x}"))
-    h2 = lambda x: display(Markdown(f"## {x}"))
-    h3 = lambda x: display(Markdown(f"### {x}"))
-    h4 = lambda x: display(Markdown(f"#### {x}"))
-    h6 = lambda x: display(Markdown(f"##### {x}"))
-    h6 = lambda x: display(Markdown(f"###### {x}"))
-
-
-def key(url):
-    return sheet(url)
-
-
-def link(gsheet_key):
-    """Return GSheet URL for data from Web UI."""
-    return 'https://docs.google.com/spreadsheets/d/%s/edit' % gsheet_key
-
+gui = "https://docs.google.com/spreadsheets/d/"
+link = lambda key: f"{gui}{key}/edit#gid=0"
+key = lambda key: sheet(key)
 
 def sheet(key):
     global gspread_authorized
     global gspread_sheet
-    global credentials
 
-    credentials = ohawf.get()
-
-    try:
-        if key[:4].lower() == "http":
-            gspread_sheet = gspread_authorized.open_by_url(key)
-        else:
-            gspread_sheet = gspread_authorized.open_by_key(key)
-        print(
-            """<<< CONNECTED! >>> You can open the Google Sheet with the following link:"""
-        )
-        if key[:4].lower() == "http":
-            print(key)
-        else:
-            print(link(key))
-    except:
-        err()
-        print("Make sure %s has permission to this document." % email())
-        raise SystemExit()
+    continue_executing = False
+    if key[:4].lower() == "http":
+        gspread_sheet = gspread_authorized.open_by_url(key)
+    else:
+        gspread_sheet = gspread_authorized.open_by_key(key)
     try:
         sheet1 = gspread_sheet.worksheets()[0].title
-        print(
-            'Try: cl, df = pipulate.pull("%s", "A1:C3") # or pipulate.help() for help.'
-            % sheet1
-        )
+        continue_executing = True
     except:
-        credentials = ohawf.get()
+        continue_executing = False
+    if key[:4].lower() == "http":
+        print(key)
+    else:
+        print(link(key))
+    if not continue_executing:
+        print("Cannot access document. Check URL/key and permissions.")
+        exit(1)
+    print("<<< CONNECTED TO SHEET! >>>")
+    print(
+        'Try: cl, df = pipulate.pull("%s", "A1:C3") # or for help type: pipulate.help()'
+        % sheet1
+    )
 
 
 def help():
@@ -173,15 +137,13 @@ def poke(tab, columns, row=1, start=1):
 
 
 def pipulate(tab, rows, cols=None, columns=None, start=None, end=None):
-    global credentials
     original_range, original_row1 = None, None
 
-    credentials = ohawf.get()
     worksheet_ = check_worksheet(tab)
 
     if gspread_sheet is None:
         print('Make sure you pipulate.sheet("key or url") first.')
-        raise SystemExit()
+        exit(1)
 
     if cols:
         row1, row2 = rows
@@ -191,12 +153,7 @@ def pipulate(tab, rows, cols=None, columns=None, start=None, end=None):
         col1, col2 = cols
         if not (type(col1) == int or type(col2) == int):
             col1, col2 = a1(col1, reverse=True), a1(col2, reverse=True)
-        try:
-            cl = worksheet_.range(row1, col1, row2, col2)
-        except:
-            credentials = ohawf.get()
-            # print('Rate quota possibly exceeded. Wait a minute and try again.')
-            # raise SystemExit()
+        cl = worksheet_.range(row1, col1, row2, col2)
         list_of_lists = cl_to_list(cl)
         if not columns:
             cell_list = worksheet_.range(row1, col1, row1, col2)
@@ -209,17 +166,13 @@ def pipulate(tab, rows, cols=None, columns=None, start=None, end=None):
         if type(columns) == bool:
             original_range = rows
             rows = shift_range(rows)
-        #try:
         cl = worksheet_.range(rows)
-        #except:
-        #    print("Rate quota possibly exceeded. Wait a minute and try again.")
-        #    raise SystemExit()
         list_of_lists = cl_to_list(cl)
         if not columns:
             columns = [a1(i + 1) for i, x in enumerate(list_of_lists[0])]
     else:
         print("Check your rows or range definition.")
-        raise SystemExit()
+        exit(1)
 
     if type(columns) == bool and columns == True:
         if cols:
@@ -233,13 +186,13 @@ def pipulate(tab, rows, cols=None, columns=None, start=None, end=None):
             print(
                 "All columns must have labels when using columns=True or columns=list."
             )
-            raise SystemExit()
+            exit(1)
         if len(set(columns)) < len(columns):
             print(columns)
             print(
                 "All columns must have labels when using columns=True or columns=list."
             )
-            raise SystemExit()
+            exit(1)
 
     df = pd.DataFrame(list_of_lists, columns=columns)
 
@@ -257,10 +210,7 @@ def pipulate(tab, rows, cols=None, columns=None, start=None, end=None):
 def populate(tab, cl, df, formulas=False):
     """Push df back to spreadsheet."""
 
-    try:
-        worksheet_ = check_worksheet(tab)
-    except:
-        credentials = ohawf.get()
+    worksheet_ = check_worksheet(tab)
 
     if cl_df_fits(cl, df):
         lol = df.values.tolist()
@@ -273,7 +223,7 @@ def populate(tab, cl, df, formulas=False):
         else:
             worksheet_.update_cells(cl)
     else:
-        raise SystemExit()
+        exit(1)
     print('pipulate.push("%s", cl, df) <<< GSHEET UPDATED! >>>' % worksheet_.title)
 
 
@@ -299,25 +249,25 @@ def check_worksheet(worksheet):
                 tab = gspread_sheet.worksheet(worksheet)
             else:
                 print("Worksheet not found")
-                raise SystemExit()
+                exit(1)
         else:
             print("pipulate.sheet([your gsheets key here]) must be set")
-            raise systemexit()
+            exit(1)
     elif type(worksheet) == int:
         if "gspread_sheet" in globals():
             if worksheet <= len(gspread_sheet.worksheets()):
                 tab = gspread_sheet.worksheets()[worksheet]
             else:
                 print("Worksheet ID too high. Try 0 for sheet 1.")
-                raise SystemExit()
+                exit(1)
         else:
             print("pipulate.sheet([your gsheets key here]) must be set")
-            raise systemexit()
+            exit(1)
     else:
         print(
             "Worksheet must be exact tab-name as string, gspread Worksheet object or tab-index."
         )
-        raise SystemExit()
+        exit(1)
     return tab
 
 
@@ -716,8 +666,6 @@ class Unbuffered(object):
 credentials = ohawf.get()
 gspread_authorized = gspread.authorize(credentials)
 
-print()
-print("CONGRATULATIONS! You are logged in as <<< %s >>>" % email())
 print('Get started with: pipulate.sheet("Insert your GSheet key or URL")')
 print("For help, run: pipulate.help()")
 
